summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmblobedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmblobedit.h')
-rw-r--r--kpovmodeler/pmblobedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmblobedit.h b/kpovmodeler/pmblobedit.h
index 5677fb9b..bada56da 100644
--- a/kpovmodeler/pmblobedit.h
+++ b/kpovmodeler/pmblobedit.h
@@ -36,12 +36,13 @@ class TQCheckBox;
class PMBlobEdit : public PMSolidObjectEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMBlobEdit with parent and name
*/
- PMBlobEdit( TQWidget* parent, const char* name = 0 );
+ PMBlobEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -36,12 +36,13 @@ class TQCheckBox;
public:
/**
- * Creates a PMBlobEdit with parent and name
+ * Creates a PMBlobEdit with tqparent and name
*/